// skin effect of a return circuit of two adjucent strap conductors
// Kouichi Hirabayashi, 2017-07-16
// Cf. H.B.Dwight,- Skin Effect of a Return Circuit of Two Adjucent Strap
//	  Conductors (The Ellectric Journal, April, 1916)

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <math.h>
#include <complex.h>

#define COMPLEX double complex

double PI;

// b << a && c << b && b < 3*sqrt(2/(2*PI*f*u*g)

COMPLEX Zac(double a, double g, double u, double f)
{
  int i;
  double m, k, fmax, rdc;
  COMPLEX z, z0, z1, z2;

  fmax = 9.0 / (PI * g * u * a * a);	// 3.0 * skin-depth
  if (fmax < f)
	fprintf(stderr, "frequency must be less than %.2e Hz for this model.\n",
		fmax);
  m = 2.0 * PI * f * u * g * a * a;
  k = 1;
  z = 1.0;
  z1 = 1.0;
  for (i = 1; i <= 10; i++) {
	k *= (double)((2 * i - 1) * 2 * i);
	z *= I * m;
	z1 += z / k;
	if (cabs((z0 - z1) / z1) < 1e-6)
		break;
	z0 = z1;
  }
  k = 1;
  z = 1.0;
  z2 = 1.0;
  for (i = 1; i <= 10; i++) {
	k *= (double)(2 * i * (2 * i + 1));
	z *= I * m;
	z2 += z / k;
	if (cabs((z0 - z2) / z2) < 1e-6)
		break;
	z0 = z2;
  }
  return z1 / z2;
}

int main(int argc, char **argv)
{
  double a, b, c, g, u, f, fmax, rdc, w;
  COMPLEX z;

  PI = atan2(0.0, -1.0);
  f = 60.0;
  g = 5.80e7;		// conductivity
  u = 4e-7 * PI;	// magnetic permeability
  a = 1.59e-3;
  b = 38.1e-3;
  c = 0.5e-3;
  rdc = 2.0 * g * a * b;
  fmax = 9.0 / (PI * g * u * a * a);	// 3.0 * skin-depth
  for (f = 1.0; f <= fmax * 1.05; f *= 1.05) {
	w = 2.0 * PI * f;
	z = Zac(a, g, u, f);
//	printf("%g %g\n", f, creal(z));		// Rac/Rdc
//	printf("%g %g %g\n", f, creal(z), cimag(z));	// Zac/Rdc
//	printf("%g %g\n", f, 2.0 * PI * u * c / b + cimag(z) / w);	// Le+Li
//	printf("%g %g\n", f, cimag(z) / w);	// Li
  }
  exit(0);
}

