// V.Belevitch,- The lateral skin effect in a flat conductor
// Philips tech. Rev. 32, 221-231, 1971, No. 6/7/8
// elliptic cross-section
// 2017-07-13 K.Hirabayashi

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <math.h>
#include <complex.h>
#define COMPLEX double complex

// Zac/Rdc elliptic cross-section conductor

COMPLEX Zac(double k, COMPLEX *p1, COMPLEX *p2)
{
  int i, n;
  COMPLEX x, z, z2, z3;

  if (k <= 0.0)
	z = 1.0;
  else {
	n = 200;
	z = 1.0 + I * k / (double)(2 * n);
	for (i = n - 1; i > 0; i--)
		z = 1.0 / (1.0 / z + 1.0 / (I * k / (double)(2 * i))) + 1.0;
  }
  // k^2 approximation
  x = I * k;
  z2 = 1.0 + 0.5 * x - 0.25 * x * x;
  // high frequency
  z3 = (0.942 + I * 0.544) * pow(k, 1.0 / 3.0);
  *p1 = z2;
  *p2 = z3;
  return z;
}

int main(int argc, char **argv)
{
  int i, n;
  double a, b, f, g, k, u, w, PI;
  COMPLEX x, z, z1, z2;

  PI = atan2(0.0, -1.0);
  for (k = 1e-2; k <= 1e3; k *= 1.1) {
	z = Zac(k, &z1, &z2);
	printf("%g %g %g\n", k, creal(z), creal(z2));
//	printf("%g %g %g\n", k, creal(z), cimag(z));
//	printf("%g %g %g %g\n", k, creal(z), creal(z1), creal(z2));
  }
  exit(0);
}
