/*
 * proximity efect in strip
 * 2017-07-08 Kouichi Hirabayashi
 * Cf.
 *   H.B.DWEIGHT,- Skin Effect in Tubular and Flat Conductors
 *	A.I.E.E. Trans. Vol 37 Part2, 1918, p1379-1403
 */

#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include <complex.h>
//#include "Complex.h"

#define COMPLEX double complex

double PI;

// a = width, c = thickness

COMPLEX Edge(double a, double c, double u, double g, double f)
{
  double w, p;
  COMPLEX z;

  p = 2.0 * PI * f * u * g * a * c;	// 2*PI*f*u/Rdc
  z = 1.0 + p * (0.5 * I + p * (-0.0149994 + p * (0.003122 * I
	+ p * (0.000532 + p * (-0.0000779 * I
	+ p * (-0.0000096 + p * (0.00000094 * I
	+ 0.00000005)))))));
  z /= 1.0 + p * (0.0965736 * I + p * (0.0152178 + p * (-0.00218 * I
	+ p * (-0.00259 + p * (0.0000237 * I + p * (0.00000100
	+ p * (0.00000022 *I + 0.00000008 * p)))))));
  return z;
}

int edge(double a, double c, double u, double g, double f1, double f2)
{
  double f, p;
  COMPLEX z;

  a *= 2.0;
  for (f = f1; f <= f2; f *= 1.05) {
	z = Edge(a, c, u, g, f);
	p = sqrt(2.0 * PI * f * u * g * a * c);	// sqrt(2*PI*f*u/Rdc)
	if (p > 2.0)
		break;	// convergence limit
	printf("%g %g\n", f, creal(z));
//	printf("%g %g %g\n", f, creal(z), cimag(z));
//	printf("%g %g %g %g\n", f, creal(z), cimag(z), p);
  }
  return 0;
}


int main(void)
{
  double a, c, s, g, u, r;

  PI = atan2(0.0, -1.0);
  a = 100e-3;		// conductor width (m)
  c = 0.5e-3;		// conductor thickness (m)
  g = 1e8 / 2.83;	// conductivity (S/m)
  u = 4e-7 * PI;	// magnetic permeability (H/m)
  edge(a, c, u, g, 1e0, 1.38e2);
  exit(0);
}
